<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Interview;
use Illuminate\Http\Request;

class InterviewController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // $interviews = Interview::all();

        $categories = Category::with('getInterviewDetail')->get();
        return view('admin.interview.index', compact('categories'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $categories = Category::all();
        return view('admin.interview.create', compact('categories'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'category_id' => 'required',
            'quest' => 'required',
            'answer' => 'required',
        ]);

        $interview = new Interview();
        $interview->category_id = $request->category_id;
        $interview->quest = $request->quest;
        $interview->answer = $request->answer;

        $interview->save();

        return redirect()->route('interview.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $categories = Category::all();
        $interview = Interview::find($id);
        return view('admin.interview.edit', compact('categories', 'interview'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'category_id' => 'required',
            'quest' => 'required',
            'answer' => 'required',
        ]);

        $interview = new Interview();
        $interview->category_id = $request->category_id;
        $interview->quest = $request->quest;
        $interview->answer = $request->answer;

        $interview->save();

        return redirect()->route('interview.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $interview = Interview::find($id);
        $interview->delete();
        return redirect()->back();
    }
}
